==> gwisp-0.0.33.tgz: package/lib/repository/region.js <==
// region repository
// using to query region in database
// params
//  - db <connection>: instance of mongoose connection
// return instance of region repository
function RegionRepository (dbclient) {
  this._collection = dbclient.collection('region')
}

// shortcut to region repository prototype
// using to access to repositoy prototype more quickly
var prototype = RegionRepository.prototype

// create new region
// params
//  - items <array|object>: list of region or one region
//  - callback <function>: function will call
//    params
//     - error <object>: error during process
prototype.create = function (items, callback) {
  this._collection.insertMany(items, function (err) {
    callback(err)
  })
}

// find region by id
// params
//  - id <string>: identify of region
//  - callback <function>: function will call
//    params
//       - error <object>: error return by process
//       - item <object>: region found
prototype.findById = function (id, callback) {
  this._collection.find({ id: id }).toArray(function (err, item) {
    callback(err, item)
  })
}

// search region by keyword
// prams
//  - keyword <string>: keyword for search
//  - selector <object>: contain option to search
//    - pageSize <number>: max item to search
//    - pageIndex <number>: page index
//  - callback <function>: function will called
//    params
//     - error <object>: error return by process
//     - items <array>: list of region matched by search
prototype.search = function (keyword, selector, callback) {
  var skip = (selector.pageIndex - 1) * selector.pageSize
  var options = {skip: skip, limit: selector.pageSize}

  var filter = keyword ? {name: {$regex: new RegExp(keyword, 'gi')}} : null
  var fields = {_id: 0}
  this._collection.find(filter, fields, options).toArray(function (err, items) {
    callback(err, items)
  })
}

// export module
module.exports = RegionRepository

==> gwisp-0.0.38.tgz: package/lib/repository/region.js <==
const imjv = require('is-my-json-valid')

const verifyInsert = imjv({
  type: 'object',
  required: true,
  properties: {
    id: {type: 'string', required: true, pattern: '^[a-z]{2}$'},
    name: {type: 'string', required: true, pattern: '^.{1,96}$'}
  }
})

function verifyItems(items) {
  for (var i = 0; i < items.length; i++) {
    if (!verifyInsert(items[i])) return false
  }

  return true
}

// region repository
// using to query region in database
// params
//  - db <connection>: instance of mongoose connection
// return instance of region repository
function RegionRepository (dbclient) {
  this._collection = dbclient.collection('region')
}

// shortcut to region repository prototype
// using to access to repositoy prototype more quickly
var prototype = RegionRepository.prototype

// create new region
// params
//  - items <array|object>: list of region or one region
//  - callback <function>: function will call
//    params
//     - error <object>: error during process
prototype.insert = function (items, callback) {
  if (!verifyItems(items)) return callback(verifyInsert.errors)

  this._collection.insertMany(items, function (err) {
    callback(err)
  })
}

// find region by id
// params
//  - id <string>: identify of region
//  - callback <function>: function will call
//    params
//       - error <object>: error return by process
//       - item <object>: region found
prototype.findById = function (id, callback) {
  this._collection.find({ id: id }).toArray(function (err, item) {
    callback(err, item)
  })
}

// search region by keyword
// prams
//  - keyword <string>: keyword for search
//  - selector <object>: contain option to search
//    - pageSize <number>: max item to search
//    - pageIndex <number>: page index
//  - callback <function>: function will called
//    params
//     - error <object>: error return by process
//     - items <array>: list of region matched by search
prototype.search = function (keyword, selector, callback) {
  var skip = (selector.pageIndex - 1) * selector.pageSize
  var options = {skip: skip, limit: selector.pageSize}

  var filter = keyword ? {name: {$regex: new RegExp(keyword, 'gi')}} : null
  var fields = {_id: 0}
  this._collection.find(filter, fields, options).toArray(function (err, items) {
    callback(err, items)
  })
}

// export module
module.exports = RegionRepository
